/*
 * MiniPC screen details and panel-specific functions.
 *
 * Copyright (C) 2005-2007, Ingenic Semiconductor Inc.
 * Copyright (C) 2015, 2016, 2017 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "board.h"
#include "jzlcd.h"
#include "minipc.h"
#include "gpio.h"

struct jzfb_info jzfb = {
	MODE_TFT_GEN | PCLK_N | HSYNC_N | VSYNC_N,
	800, 480, 32, 60, 80, 20, 0, 0, 0, 0
};

vidinfo_t panel_info = {
	.jz_fb=&jzfb,	// this will need correcting for user mode usage
	.lcd=0,		// base address for registers
};

void lcd_set_backlight_level(uint16_t n)
{
	jz4740_gpio_as_pwm((void *) GPIO_BASE, 0);
	REG_PWM_DUT(0) = n;
	REG_PWM_PER(0) = 7;
	REG_PWM_CTR(0) = 0xc1;
}

void lcd_close_backlight()
{
	void *gpio_port_base = jz4740_gpio_get_port((void *) GPIO_BASE, GPIO_PORT_PWM);
	jz4740_gpio_as_output(gpio_port_base, GPIO_PWM0);
	jz4740_gpio_clear_pin(gpio_port_base, GPIO_PWM0);
}

void lcd_display_pin_init()
{
	void *gpio_port_base = jz4740_gpio_get_port((void *) GPIO_BASE, GPIO_PORT_LED);
	jz4740_gpio_as_output(gpio_port_base, GPIO_DISP_OFF_N);
	lcd_set_backlight_level(8);
}

void lcd_display_on()
{
	void *gpio_port_base = jz4740_gpio_get_port((void *) GPIO_BASE, GPIO_PORT_LED);
	jz4740_gpio_set_pin(gpio_port_base, GPIO_DISP_OFF_N);
	lcd_set_backlight_level(8);
}

void lcd_display_off()
{
	void *gpio_port_base = jz4740_gpio_get_port((void *) GPIO_BASE, GPIO_PORT_LED);
	lcd_close_backlight();
	jz4740_gpio_clear_pin(gpio_port_base, GPIO_DISP_OFF_N);
}
